@@ -13,15 +13,17 @@ import (
 	"syscall"
 	"text/tabwriter"
 
+	"github.com/variantdev/vals"
+	"go.uber.org/zap"
+
 	"github.com/helmfile/helmfile/pkg/argparser"
 	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/helmfile/helmfile/pkg/plugins"
 	"github.com/helmfile/helmfile/pkg/remote"
 	"github.com/helmfile/helmfile/pkg/state"
-	"github.com/variantdev/vals"
-	"go.uber.org/zap"
 )
 
+// App is the main application object.
 type App struct {
 	OverrideKubeContext string
 	OverrideHelmBinary  string
@@ -552,8 +554,7 @@ func (a *App) ListReleases(c ListConfigProvider) error {
 			SkipRepos: true,
 			SkipDeps:  true,
 		}, func() {
-
-			//var releases m
+			// var releases m
 			for _, r := range run.state.Releases {
 				labels := ""
 				if r.Labels == nil {
@@ -805,7 +806,7 @@ func (a *App) visitStates(fileOrDir string, defOpts LoadOpts, converge func(*sta
 						Reverse:           defOpts.Reverse,
 						RetainValuesFiles: defOpts.RetainValuesFiles,
 					}
-					//assign parent selector to sub helm selector in legacy mode or do not inherit in experimental mode
+					// assign parent selector to sub helm selector in legacy mode or do not inherit in experimental mode
 					if (m.Selectors == nil && !isExplicitSelectorInheritanceEnabled()) || m.SelectorsInherited {
 						optsForNestedState.Selectors = opts.Selectors
 					} else {
@@ -915,11 +916,12 @@ func printBatches(batches [][]state.Release) string {
 		fmt.Fprintf(w, "%d\t%s\n", i+1, strings.Join(ids, ", "))
 	}
 
-	w.Flush()
+	_ = w.Flush()
 
 	return buf.String()
 }
 
+// nolint: unparam
 func withDAG(templated *state.HelmState, helm helmexec.Interface, logger *zap.SugaredLogger, opts state.PlanOptions, converge func(*state.HelmState, helmexec.Interface) (bool, []error)) (bool, []error) {
 	batches, err := templated.PlanReleases(opts)
 	if err != nil {
@@ -985,7 +987,7 @@ func (a *App) visitStatesWithSelectorsAndRemoteSupport(fileOrDir string, converg
 		envvals = append(envvals, v)
 	}
 
-	if a.Set != nil {
+	if len(a.Set) > 0 {
 		envvals = append(envvals, a.Set)
 	}
 
@@ -1092,11 +1094,12 @@ func (a *App) findDesiredStateFiles(specifiedPath string, opts LoadOpts) ([]stri
 
 	var helmfileDir string
 	if specifiedPath != "" {
-		if a.fileExistsAt(specifiedPath) {
+		switch {
+		case a.fileExistsAt(specifiedPath):
 			return []string{specifiedPath}, nil
-		} else if a.directoryExistsAt(specifiedPath) {
+		case a.directoryExistsAt(specifiedPath):
 			helmfileDir = specifiedPath
-		} else {
+		default:
 			return []string{}, fmt.Errorf("specified state file %s is not found", specifiedPath)
 		}
 	} else {
@@ -1113,15 +1116,16 @@ func (a *App) findDesiredStateFiles(specifiedPath string, opts LoadOpts) ([]stri
 			defaultFile = DeprecatedHelmfile
 		}
 
-		if a.directoryExistsAt(DefaultHelmfileDirectory) {
+		switch {
+		case a.directoryExistsAt(DefaultHelmfileDirectory):
 			if defaultFile != "" {
 				return []string{}, fmt.Errorf("configuration conlict error: you can have either %s or %s, but not both", defaultFile, DefaultHelmfileDirectory)
 			}
 
 			helmfileDir = DefaultHelmfileDirectory
-		} else if defaultFile != "" {
+		case defaultFile != "":
 			return []string{defaultFile}, nil
-		} else {
+		default:
 			return []string{}, fmt.Errorf("no state file found. It must be named %s/*.{yaml,yml} or %s, otherwise specified with the --file flag", DefaultHelmfileDirectory, DefaultHelmfile)
 		}
 	}
@@ -1944,6 +1948,7 @@ func directoryExistsAt(path string) bool {
 	return err == nil && fileInfo.Mode().IsDir()
 }
 
+// Error is a wrapper around an error that adds context to the error.
 type Error struct {
 	msg string
 
@@ -2056,7 +2061,7 @@ func (c context) wrapErrs(errs ...error) error {
 	return nil
 }
 
-func (a *App) ShowCacheDir(c ListConfigProvider) error {
+func (a *App) ShowCacheDir(c CacheConfigProvider) error {
 	fmt.Printf("Cache directory: %s\n", remote.CacheDir())
 
 	if !directoryExistsAt(remote.CacheDir()) {
@@ -2073,7 +2078,7 @@ func (a *App) ShowCacheDir(c ListConfigProvider) error {
 	return nil
 }
 
-func (a *App) CleanCacheDir(c ListConfigProvider) error {
+func (a *App) CleanCacheDir(c CacheConfigProvider) error {
 	if !directoryExistsAt(remote.CacheDir()) {
 		return nil
 	}
@@ -2084,7 +2089,10 @@ func (a *App) CleanCacheDir(c ListConfigProvider) error {
 	}
 	for _, e := range dirs {
 		fmt.Printf("- %s\n", e.Name())
-		os.RemoveAll(filepath.Join(remote.CacheDir(), e.Name()))
+		err := os.RemoveAll(filepath.Join(remote.CacheDir(), e.Name()))
+		if err != nil {
+			return err
+		}
 	}
 
 	return nil
