@@ -9,10 +9,11 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
+	"github.com/variantdev/vals"
+
 	"github.com/helmfile/helmfile/pkg/exectest"
 	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/helmfile/helmfile/pkg/testhelper"
-	"github.com/variantdev/vals"
 )
 
 func TestApply_2(t *testing.T) {
@@ -1275,7 +1276,7 @@ foo 	4       	Fri Nov  1 08:40:07 2019	DEPLOYED	raw-3.1.0	3.1.0      	default
 		})
 	})
 
-	t.Run("select non existant release with --allow-no-matching-release", func(t *testing.T) {
+	t.Run("select non existent release with --allow-no-matching-release", func(t *testing.T) {
 		check(t, testcase{
 			files: map[string]string{
 				"/path/to/helmfile.yaml": `
