@@ -8,10 +8,11 @@ import (
 	"sync"
 	"testing"
 
+	"github.com/variantdev/vals"
+
 	"github.com/helmfile/helmfile/pkg/exectest"
 	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/helmfile/helmfile/pkg/testhelper"
-	"github.com/variantdev/vals"
 )
 
 func TestDestroy_2(t *testing.T) {
@@ -108,11 +109,12 @@ func TestDestroy_2(t *testing.T) {
 				includeTransitiveNeeds: false,
 			})
 
-			if tc.error == "" && destroyErr != nil {
+			switch {
+			case tc.error == "" && destroyErr != nil:
 				t.Fatalf("unexpected error: %v", destroyErr)
-			} else if tc.error != "" && destroyErr == nil {
+			case tc.error != "" && destroyErr == nil:
 				t.Fatal("expected error did not occur")
-			} else if tc.error != "" && destroyErr != nil && tc.error != destroyErr.Error() {
+			case tc.error != "" && destroyErr != nil && tc.error != destroyErr.Error():
 				t.Fatalf("invalid error: expected %q, got %q", tc.error, destroyErr.Error())
 			}
 
