@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"io"
 	"os"
-
 	"strings"
 
 	"github.com/jessevdk/go-flags"
@@ -113,10 +112,10 @@ func computeDiff(formatter aurora.Aurora, a interface{}, b interface{}) (string,
 		switch {
 		case strings.HasPrefix(s, "+"):
 			diffs = append(diffs, formatter.Bold(formatter.Green(s)).String())
-			ndiffs += 1
+			ndiffs++
 		case strings.HasPrefix(s, "-"):
 			diffs = append(diffs, formatter.Bold(formatter.Red(s)).String())
-			ndiffs += 1
+			ndiffs++
 		default:
 			diffs = append(diffs, s)
 		}
